@@ -1,9 +1,9 @@
 #include <string.h>
 #include <stdlib.h>
 #include <stdio.h>
+#include <ctype.h>
 
 #include "hyphen.h"
-#include "csutil.h"
 
 #define BUFSIZE 1000
 
@@ -12,6 +12,7 @@ void help() {
     fprintf(stderr,"example [-d | -dd] hyphen_dictionary_file file_of_words_to_check\n");
     fprintf(stderr,"-o = use old algorithm (without non-standard hyphenation)\n");
     fprintf(stderr,"-d = hyphenation with listing of the possible hyphenations\n");
+    fprintf(stderr,"-n = print hyphenation vector\n");
 }
 
 /* get a pointer to the nth 8-bit or UTF-8 character of the word */
@@ -69,6 +70,7 @@ main(int argc, char** argv)
     char hword[BUFSIZE * 2];
     int arg = 1;
     int optd = 1;
+    int optn = 0;
     int optdd = 0;
     char ** rep;
     int * pos;
@@ -82,6 +84,10 @@ main(int argc, char** argv)
             optd = 0;
             arg++;
        }
+       if (strcmp(argv[arg], "-n") == 0) {
+            optn = 1;
+            arg++;
+       }
        if (argv[arg] && strcmp(argv[arg], "-d") == 0) {
             optd = 1;
             optdd = 1;
@@ -119,7 +125,7 @@ main(int argc, char** argv)
 
     
   /* now read each word from the wtc file */
-    while(fgets(buf,BUFSIZE,wtclst)) {
+    while(fgets(buf,BUFSIZE,wtclst) != NULL) {
        k = strlen(buf);
        if (buf[k - 1] == '\n') buf[k - 1] = '\0';
        if (*buf && buf[k - 2] == '\r') buf[k-- - 2] = '\0';
@@ -128,11 +134,9 @@ main(int argc, char** argv)
        /* and hyphen information */
        lcword = (char *) malloc(k+1);
        hyphens = (char *)malloc(k+5);
-       if (dict->utf8) {
-         strcpy(lcword, buf);
-       } else {
-         enmkallsmall(lcword,buf,dict->cset);
-       }
+       /* basic ascii lower-case, not suitable for real-world usage*/
+       for (i = 0; i < k; ++i)
+         lcword[i] = tolower(buf[i]);
 
        /* first remove any trailing periods */
        n = k-1;
@@ -154,6 +158,8 @@ main(int argc, char** argv)
              exit(1);
        }
 
+       if (optn) fprintf(stderr, "%s\n", hyphens); 
+
        if (!optd) {
          /* now backfill hyphens[] for any removed periods */
          for (c = n; c < k; c++) hyphens[c] = '0';
@@ -178,7 +184,6 @@ main(int argc, char** argv)
          fflush(stdout);
          free(hyphword);
       } else {
-/*         fprintf(stderr, "vasz: %s", hyphens); */
          fprintf(stdout,"%s\n", hword);
 
 
